@@ -6,7 +6,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '2.21';
+our $VERSION = '2.35';
 
 use DateTime::TimeZone::Catalog;
 use DateTime::TimeZone::Floating;
@@ -21,7 +21,7 @@ use Specio::Library::String;
 use Try::Tiny;
 
 ## no critic (ValuesAndExpressions::ProhibitConstantPragma)
-use constant INFINITY => 100**1000;
+use constant INFINITY     => 100**1000;
 use constant NEG_INFINITY => -1 * ( 100**1000 );
 
 # the offsets for each span element
@@ -602,7 +602,7 @@ DateTime::TimeZone - Time zone object base class and factory
 
 =head1 VERSION
 
-version 2.21
+version 2.35
 
 =head1 SYNOPSIS
 
@@ -858,27 +858,6 @@ Starman), then you should try to load all the time zones that you'll need in
 the parent process. Time zones are loaded on-demand, so loading them once in
 each child will waste memory that could otherwise be shared.
 
-=head1 DONATIONS
-
-If you'd like to thank me for the work I've done on this module,
-please consider making a "donation" to me via PayPal. I spend a lot of
-free time creating free software, and would appreciate any support
-you'd care to offer.
-
-Please note that B<I am not suggesting that you must do this> in order
-for me to continue working on this particular software. I will
-continue to do so, inasmuch as I have in the past, for as long as it
-interests me.
-
-Similarly, a donation made in this way will probably not make me work
-on this software much more, unless I get so many donations that I can
-consider working on free software full time, which seems unlikely at
-best.
-
-To donate, log into PayPal and send money to autarch@urth.org or use
-the button on this page:
-L<http://www.urth.org/~autarch/fs-donation.html>
-
 =head1 CREDITS
 
 This module was inspired by Jesse Vincent's work on
@@ -936,7 +915,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alexey Molchanov Alfie John Bron Gondwana Daisuke Maki David Pinkowitz Iain Truskett Jakub Wilk James E Keenan Joshua Hoblitt Karen Etheridge karupanerura Mohammad S Anwar Olaf Alders Peter Rabbitson Tom Wyant
+=for stopwords Alexey Molchanov Alfie John Andrew Paprocki Bron Gondwana Daisuke Maki David Pinkowitz Iain Truskett Jakub Wilk James E Keenan Joshua Hoblitt Karen Etheridge karupanerura Mohammad S Anwar Olaf Alders Peter Rabbitson Tom Wyant
 
 =over 4
 
@@ -950,6 +929,10 @@ Alfie John <alfiej@fastmail.fm>
 
 =item *
 
+Andrew Paprocki <apaprocki@bloomberg.net>
+
+=item *
+
 Bron Gondwana <brong@fastmail.fm>
 
 =item *
@@ -1004,7 +987,7 @@ Tom Wyant <wyant@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Dave Rolsky.
+This software is copyright (c) 2019 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
